"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var GRAPHIQL_VERSION = '0.10.2';
var SUBSCRIPTIONS_TRANSPORT_VERSION = '0.7.0';
function safeSerialize(data) {
    return data ? JSON.stringify(data).replace(/\//g, '\\/') : null;
}
function renderGraphiQL(data) {
    var endpointURL = data.endpointURL;
    var subscriptionsEndpoint = data.subscriptionsEndpoint;
    var usingSubscriptions = !!subscriptionsEndpoint;
    var queryString = data.query;
    var variablesString = data.variables ? JSON.stringify(data.variables, null, 2) : null;
    var resultString = null;
    var operationName = data.operationName;
    var passHeader = data.passHeader ? data.passHeader : '';
    return "\n<!DOCTYPE html>\n<html>\n<head>\n  <meta charset=\"utf-8\" />\n  <title>GraphiQL</title>\n  <meta name=\"robots\" content=\"noindex\" />\n  <style>\n    html, body {\n      height: 100%;\n      margin: 0;\n      overflow: hidden;\n      width: 100%;\n    }\n  </style>\n  <link href=\"//cdn.jsdelivr.net/graphiql/" + GRAPHIQL_VERSION + "/graphiql.css\" rel=\"stylesheet\" />\n  <script src=\"//cdn.jsdelivr.net/fetch/0.9.0/fetch.min.js\"></script>\n  <script src=\"//cdn.jsdelivr.net/react/15.0.0/react.min.js\"></script>\n  <script src=\"//cdn.jsdelivr.net/react/15.0.0/react-dom.min.js\"></script>\n  <script src=\"//cdn.jsdelivr.net/graphiql/" + GRAPHIQL_VERSION + "/graphiql.min.js\"></script>\n  " + (usingSubscriptions ?
        "<script src=\"//unpkg.com/subscriptions-transport-ws@" + SUBSCRIPTIONS_TRANSPORT_VERSION + "/browser/client.js\"></script>" +
            '<script src="//unpkg.com/graphiql-subscriptions-fetcher@0.0.2/browser/client.js"></script>'
        : '') + "\n</head>\n<body>\n  <script>\n    // Collect the URL parameters\n    var parameters = {};\n    window.location.search.substr(1).split('&').forEach(function (entry) {\n      var eq = entry.indexOf('=');\n      if (eq >= 0) {\n        parameters[decodeURIComponent(entry.slice(0, eq))] =\n          decodeURIComponent(entry.slice(eq + 1));\n      }\n    });\n    // Produce a Location query string from a parameter object.\n    function locationQuery(params, location) {\n      return (location ? location: '') + '?' + Object.keys(params).map(function (key) {\n        return encodeURIComponent(key) + '=' +\n          encodeURIComponent(params[key]);\n      }).join('&');\n    }\n    // Derive a fetch URL from the current URL, sans the GraphQL parameters.\n    var graphqlParamNames = {\n      query: true,\n      variables: true,\n      operationName: true\n    };\n    var otherParams = {};\n    for (var k in parameters) {\n      if (parameters.hasOwnProperty(k) && graphqlParamNames[k] !== true) {\n        otherParams[k] = parameters[k];\n      }\n    }\n\n    var fetcher;\n\n    if (" + usingSubscriptions + ") {\n      var subscriptionsClient = new window.SubscriptionsTransportWs.SubscriptionClient('" + subscriptionsEndpoint + "', {\n        reconnect: true\n      });\n      fetcher = window.GraphiQLSubscriptionsFetcher.graphQLFetcher(subscriptionsClient, graphQLFetcher);\n    } else {\n      fetcher = graphQLFetcher;\n    }\n\n    // We don't use safe-serialize for location, because it's not client input.\n    var fetchURL = locationQuery(otherParams, '" + endpointURL + "');\n\n    // Defines a GraphQL fetcher using the fetch API.\n    function graphQLFetcher(graphQLParams) {\n        return fetch(fetchURL, {\n          method: 'post',\n          headers: {\n            'Accept': 'application/json',\n            'Content-Type': 'application/json',\n            " + passHeader + "\n          },\n          body: JSON.stringify(graphQLParams),\n          credentials: 'include',\n        }).then(function (response) {\n          return response.text();\n        }).then(function (responseBody) {\n          try {\n            return JSON.parse(responseBody);\n          } catch (error) {\n            return responseBody;\n          }\n        });\n    }\n    // When the query and variables string is edited, update the URL bar so\n    // that it can be easily shared.\n    function onEditQuery(newQuery) {\n      parameters.query = newQuery;\n      updateURL();\n    }\n    function onEditVariables(newVariables) {\n      parameters.variables = newVariables;\n      updateURL();\n    }\n    function onEditOperationName(newOperationName) {\n      parameters.operationName = newOperationName;\n      updateURL();\n    }\n    function updateURL() {\n      history.replaceState(null, null, locationQuery(parameters) + window.location.hash);\n    }\n    // Render <GraphiQL /> into the body.\n    ReactDOM.render(\n      React.createElement(GraphiQL, {\n        fetcher: fetcher,\n        onEditQuery: onEditQuery,\n        onEditVariables: onEditVariables,\n        onEditOperationName: onEditOperationName,\n        query: " + safeSerialize(queryString) + ",\n        response: " + safeSerialize(resultString) + ",\n        variables: " + safeSerialize(variablesString) + ",\n        operationName: " + safeSerialize(operationName) + ",\n      }),\n      document.body\n    );\n  </script>\n</body>\n</html>";
}
exports.renderGraphiQL = renderGraphiQL;
//# sourceMappingURL=renderGraphiQL.js.map